==> vokoscreen_2.1.0.orig.tar.gz: vokoscreen-2.1.0/language/vokoscreen_pl_PL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Urządzenie zajęte</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Wyślij ostatnie nagranie</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Wyślij jedno lub kilka nagrań</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Nagranie wideo znajduje się w załączniku</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Wybierz jeden lub wiele plików</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Ramka</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Urządzenie zajęte</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Obszar</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Powiększenie</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Domyślne</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nie nagrywaj kursora myszy</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ścieżka wideo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Odtwarzacz</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Zminimalizuj vokoscreen podczas nagrywania</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Odtwórz</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Czas nagrywania</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Rozmiar w KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Rozmiar nagrywanego obrazu</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Ustawiona liczba klatek</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Wybierz katalog</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odliczanie</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Odtwórz ostatnie nagranie</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Wyślij nagranie</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Wybierz jedno lub wiele urządzeń</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktualna liczba klatek na sekundę</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Wznów</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Strona domowa</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Lista mailingowa</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Wsparcie</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Programista</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Klatki</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Darowizna</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Program nagrywający</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tłumaczenia</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kod źródłowy</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Pokazuj w tacce systemowej</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Dostępna jest nowa wersja</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Kodek wideo</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Kodek audio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Wybierz kamerę</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_pl_PL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl_PL" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Urządzenie zajęte</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nieznane</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Urządzenie</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>W użyciu przez</translation>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Wyślij ostatnie nagranie</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Wyślij jedno lub kilka nagrań</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Zainstaluj odtwarzacz wideo</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Nagranie wideo znajduje się w załączniku</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Wybierz jeden lub wiele plików</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Ramka</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Pokarz nad pełnym ekranem</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Urządzenie zajęte</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Urządzenie</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>W użyciu przez</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nieznane</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Obszar</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Powiększenie</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Domyślne</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nie nagrywaj kursora myszy</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ścieżka wideo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Odtwarzacz</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Zminimalizuj vokoscreen podczas nagrywania</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Odtwórz</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Czas nagrywania</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Rozmiar w KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Rozmiar nagrywanego obrazu</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Ustawiona liczba klatek</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Wybierz katalog</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odliczanie</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Odtwórz ostatnie nagranie</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Wyślij nagranie</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Wybierz jedno lub wiele urządzeń</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktualna liczba klatek na sekundę</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Wznów</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Strona domowa</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Wsparcie</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Programista</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Klatki</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Darowizna</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Program nagrywający</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tłumaczenia</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kod źródłowy</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Pokazuj w tacce systemowej</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Dostępna jest nowa wersja</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Kodek wideo</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Kodek audio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Wybierz kamerę</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Odbicie lustrzane</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Wyświetlacz</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Wszystkie wyświetlacze</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Strona programisty</translation>
    </message>
</context>
</TS>
